Masterful GUI is a web application for understanding the actions and outputs of the Masterful AutoML platform.

The masterful-gui package is automatically installed when installing the masterful package. For more information, see https://pypi.python.org/pypi/masterful.